

rm(list=ls())

#setwd("/Volumes/encrypted/ccasanet/gabriela")
# setwd("~/Dropbox/datasim/long-term-mortality")

load("d-second-chunk.Rda")

#save(d,file="d-second-chunk-psresiduals.Rda")  ## Saving dataset for probability-scale residuals paper.

library(survival)
library(rms)
library(mvtnorm)
library(mi)

d<-within(d,{
  site<-as.factor(site)
})



d<-d[which(d$time>0),]

#### Univariate analyses

d$male<-as.numeric(d$male)

time<-d$time
death1<-d$death1
site<-d$site
male<-d$male
age<-d$age
cd4<-d$nadir.cd4.prehaart
year<-d$year.init
aids.enrollment<-ifelse(d$aids.enrollment=="Unknown",NA,ifelse(d$aids.enrollment=="AIDS",1,0))
init.class.cat<-ifelse(d$init.class=="Other"|d$init.class=="Unboosted PI",
                       "Other",as.character(d$init.class))
init.class.cat<-factor(init.class.cat, levels=c("NNRTI","Boosted PI","Other"), ordered=TRUE)

dd<-datadist(time,death1,site,male,age,cd4,year,aids.enrollment,init.class.cat)
options(datadist="dd")

mod.male.death<-coxph(Surv(time,death1)~male+strata(site))
mod.age.death<-cph(Surv(time,death1)~rcs(age,4)+strat(site))
mod.aids.death<-coxph(Surv(time,death1)~aids.enrollment+strata(site))
mod.cd4.death<-cph(Surv(time,death1)~rcs(sqrt(cd4),4)+strat(site))
mod.year.death<-cph(Surv(time,death1)~rcs(year,4)+strat(site))   #removed non-linear piece
mod.class.death<-coxph(Surv(time,death1)~init.class.cat+strata(site))


hr.male.d<-summary(mod.male.death)$conf.int[c(1,3,4)]
p.male.d<-summary(mod.male.death)$logtest[3]

p.age.d<-anova(mod.age.death)[3,3]
hr.age.d<-rbind(summary(mod.age.death,age=c(30,20))[2,c(4,6,7)],
                summary(mod.age.death,age=c(30,40))[2,c(4,6,7)],
                summary(mod.age.death,age=c(30,50))[2,c(4,6,7)],
                summary(mod.age.death,age=c(30,60))[2,c(4,6,7)])

hr.aids.d<-summary(mod.aids.death)$conf.int[c(1,3,4)]
p.aids.d<-summary(mod.aids.death)$logtest[3]

p.cd4.d<-anova(mod.cd4.death)[3,3]
hr.cd4.d<-rbind(summary(mod.cd4.death,cd4=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd4.death,cd4=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd4.death,cd4=c(350,200))[2,c(4,6,7)])

p.year.d<-anova(mod.year.death)[3,3]
hr.year.d<-rbind(summary(mod.year.death,year=c(2006,2000))[2,c(4,6,7)],
                 summary(mod.year.death,year=c(2006,2002))[2,c(4,6,7)],
                 summary(mod.year.death,year=c(2006,2004))[2,c(4,6,7)],
                 summary(mod.year.death,year=c(2006,2008))[2,c(4,6,7)],
                 summary(mod.year.death,year=c(2006,20010))[2,c(4,6,7)])

hr.class.d<-summary(mod.class.death)$conf.int[,c(1,3,4)]
p.class.d<-c(summary(mod.class.death)$logtest[3],
                 summary(mod.class.death)$coeff[,5])


save(hr.male.d,hr.age.d,hr.cd4.d,hr.year.d,hr.aids.d,hr.class.d,
      p.male.d, p.age.d, p.cd4.d, p.year.d, p.aids.d, p.class.d,
     file="hr-death-unadjust.Rda")




#### Multiple imputation 

d.analysis<-data.frame(male,age,sqrt(cd4),year,site,
                       log(time),death1,log(time)*death1,aids.enrollment,
                       init.class.cat)
         
M<-10
IMP<-mi(d.analysis,n.chains=M,seed=20121129)     # The actual imputation

#save(IMP,file="imputed-data.Rda")

dd1 <- data.frame(complete(IMP,m=1))
dd1$death1 <- as.numeric(dd1$death1)
dd1$init.class.cat <- as.factor(as.character(dd1$init.class.cat))
dd1$aids.enrollment <- as.numeric(dd1$aids.enrollment)
dd1$male <- as.numeric(dd1$male)

imputations <- complete(IMP,m=10)

dd<-datadist(dd1)
options(datadist="dd")
ests1<-ses1<-matrix(NA,M,16)
Pars<-matrix(NA,M,13)
VarCov<-matrix(NA,M,13^2)
pred.surv.a1<-matrix(NA,M,length(unique(d$time[d$death1==1&d$site=="argentina"])))
pred.surv.b1<-matrix(NA,M,length(unique(d$time[d$death1==1&d$site=="brazil"])))
pred.surv.c1<-matrix(NA,M,length(unique(d$time[d$death1==1&d$site=="chile"])))
pred.surv.h1<-matrix(NA,M,length(unique(d$time[d$death1==1&d$site=="haiti"])))
pred.surv.ho1<-matrix(NA,M,length(unique(d$time[d$death1==1&d$site=="honduras"])))
pred.surv.m1<-matrix(NA,M,length(unique(d$time[d$death1==1&d$site=="mexico"])))
pred.surv.p1<-matrix(NA,M,length(unique(d$time[d$death1==1&d$site=="peru"])))
for (i in 1:M) {
  d.imp<-imputations[[i]]
  d.imp$death1 <- as.numeric(d.imp$death1)
  d.imp$male <- as.numeric(d.imp$male)
  d.imp$aids.enrollment <- as.numeric(d.imp$aids.enrollment)
  d.imp$init.class.cat <- as.factor(as.character(d.imp$init.class.cat))
  
  mod1<-cph(Surv(exp(log.time.),death1)~male+rcs(age,4)+aids.enrollment+rcs(sqrt.cd4.,4)+rcs(year,4)+init.class.cat+strat(site),
            data=d.imp,y=TRUE,x=TRUE)
  stuff1<-summary(mod1,age=c(30,20),sqrt.cd4.=c(sqrt(350),sqrt(50)),year=c(2006,2000))[
                                                  c("male","age","aids.enrollment","sqrt.cd4.","year",
                                                    "init.class.cat - Boosted PI:NNRTI",
                                                    "init.class.cat - Other:NNRTI"),c(4,5)]
  stuff2<-summary(mod1,age=c(30,40),sqrt.cd4.=c(sqrt(350),sqrt(100)),year=c(2006,2002))[
             c("age","sqrt.cd4.","year"),c(4,5)]
  stuff3<-summary(mod1,age=c(30,50),sqrt.cd4.=c(sqrt(350),sqrt(200)),year=c(2006,2004))[
    c("age","sqrt.cd4.","year"),c(4,5)]
  stuff4<-summary(mod1,age=c(30,60),year=c(2006,2008))[c("age","year"),c(4,5)]
  stuff5<-summary(mod1,year=c(2006,2010))[c("year"),c(4,5)]
  
  ans<-rbind(stuff1["male",],
        stuff1["age",],
        stuff2["age",],
        stuff3["age",],
        stuff4["age",],
        stuff1["aids.enrollment",],
        stuff1["sqrt.cd4.",],
        stuff2["sqrt.cd4.",],
        stuff3["sqrt.cd4.",],
        stuff1["year",],
        stuff2["year",],
        stuff3["year",],
        stuff4["year",],
        stuff5,
        stuff1["init.class.cat - Boosted PI:NNRTI",],
        stuff1["init.class.cat - Other:NNRTI",])
  
  ests1[i,]<-ans[,1]
  ses1[i,]<-ans[,2]
  
  Pars[i,]<-mod1$coeff
  VarCov[i,]<-matrix(mod1$var,nrow=1)
  
  which.age<-which(names(mod1$coeff)%in%c("age","age'","age''"))
  which.cd4<-which(names(mod1$coeff)%in%c("sqrt.cd4.","sqrt.cd4.'","sqrt.cd4.''"))
  which.year<-which(names(mod1$coeff)%in%c("year","year'","year''"))
  which.class<-which(names(mod1$coeff)%in%c("init.class.cat=Boosted PI","init.class.cat=Other"))
  
  #####  New stuff to predict survival after adjusting for covariates
  lp<-predict(mod1)
  base.haz<-basehaz(mod1)
  bh.est<-base.haz$hazard
  bh.time<-base.haz$time
  bh.site<-base.haz$strata
  
  pred.surv.a<-matrix(NA,nrow=sum(d.imp$site=="argentina"),ncol=sum(bh.site=="site=argentina"))
  for (j in 1:sum(bh.site=="site=argentina")){
    pred.surv.a[,j]<-exp(-bh.est[bh.site=="site=argentina"])[j]^exp(lp[d.imp$site=="argentina"])
  }
  pred.surv.a1[i,]<-apply(pred.surv.a,2,mean)
  
  pred.surv.b<-matrix(NA,nrow=sum(d.imp$site=="brazil"),ncol=sum(bh.site=="site=brazil"))
  for (j in 1:sum(bh.site=="site=brazil")){
    pred.surv.b[,j]<-exp(-bh.est[bh.site=="site=brazil"])[j]^exp(lp[d.imp$site=="brazil"])
  }
  pred.surv.b1[i,]<-apply(pred.surv.b,2,mean)
  
  pred.surv.c<-matrix(NA,nrow=sum(d.imp$site=="chile"),ncol=sum(bh.site=="site=chile"))
  for (j in 1:sum(bh.site=="site=chile")){
    pred.surv.c[,j]<-exp(-bh.est[bh.site=="site=chile"])[j]^exp(lp[d.imp$site=="chile"])
  }
  pred.surv.c1[i,]<-apply(pred.surv.c,2,mean)
  
  pred.surv.h<-matrix(NA,nrow=sum(d.imp$site=="haiti"),ncol=sum(bh.site=="site=haiti"))
  for (j in 1:sum(bh.site=="site=haiti")){
    pred.surv.h[,j]<-exp(-bh.est[bh.site=="site=haiti"])[j]^exp(lp[d.imp$site=="haiti"])
  }
  pred.surv.h1[i,]<-apply(pred.surv.h,2,mean)
  
  pred.surv.ho<-matrix(NA,nrow=sum(d.imp$site=="honduras"),ncol=sum(bh.site=="site=honduras"))
  for (j in 1:sum(bh.site=="site=honduras")){
    pred.surv.ho[,j]<-exp(-bh.est[bh.site=="site=honduras"])[j]^exp(lp[d.imp$site=="honduras"])
  }
  pred.surv.ho1[i,]<-apply(pred.surv.ho,2,mean)
  
  pred.surv.m<-matrix(NA,nrow=sum(d.imp$site=="mexico"),ncol=sum(bh.site=="site=mexico"))
  for (j in 1:sum(bh.site=="site=mexico")){
    pred.surv.m[,j]<-exp(-bh.est[bh.site=="site=mexico"])[j]^exp(lp[d.imp$site=="mexico"])
  }
  pred.surv.m1[i,]<-apply(pred.surv.m,2,mean)
  
  pred.surv.p<-matrix(NA,nrow=sum(d.imp$site=="peru"),ncol=sum(bh.site=="site=peru"))
  for (j in 1:sum(bh.site=="site=peru")){
    pred.surv.p[,j]<-exp(-bh.est[bh.site=="site=peru"])[j]^exp(lp[d.imp$site=="peru"])
  }
  pred.surv.p1[i,]<-apply(pred.surv.p,2,mean)
  
}

ests<-ests1
ses<-ses1

log.hr<-apply(ests,2,mean)
ses.log.hr<-sqrt(apply(ses^2,2,mean)+(M+1)*apply(ests,2,var)/M)
hr<-exp(log.hr)
hr.lower<-exp(log.hr-1.96*ses.log.hr)
hr.upper<-exp(log.hr+1.96*ses.log.hr)
p.val<-2*pnorm(-abs(log.hr/ses.log.hr))

mi.information<-solve(matrix(apply(VarCov,2,mean)+(M+1)*apply(VarCov,2,var)/M,nrow=13,ncol=13))
mean.Pars<-apply(Pars,2,mean)
pval.age.d<-1-pchisq(mean.Pars[which.age]%*%mi.information[which.age,which.age]%*%mean.Pars[which.age],length(which.age))
pval.cd4.d<-1-pchisq(mean.Pars[which.cd4]%*%mi.information[which.cd4,which.cd4]%*%mean.Pars[which.cd4],length(which.cd4))
pval.year.d<-1-pchisq(mean.Pars[which.year]%*%mi.information[which.year,which.year]%*%mean.Pars[which.year],length(which.year))
pval.init.class.cat.d<-1-pchisq(mean.Pars[which.class]%*%mi.information[which.class,which.class]%*%mean.Pars[which.class],length(which.class))

hr.adj.d<-data.frame(label=c("male","age 20:30","age 40:30","age 50:30","age 60:30","aids.enrollment",
                             "cd4 50:350","cd4 100:350","cd4 200:350",
                             "year 2000:2006","year 2002:2006","year 2004:2006","year 2008:2006","year 2010:2006",
                             "init.class.cat Boosted PI:NNRTI","init.class.cat Other:NNRTI"),
           cbind(hr,hr.lower,hr.upper,p.val))
  
save(hr.adj.d,pval.age.d,pval.cd4.d,pval.year.d,pval.init.class.cat.d,
     file="hr-death-adjust.Rda")



d.imp<-dd1
d.imp$time<-exp(d.imp$log.time.)
dd<-datadist(d.imp)
options(datadist="dd")
mod1<-cph(Surv(time,death1)~male+rcs(age,4)+aids.enrollment+rcs(sqrt.cd4.,4)+rcs(year,4)+init.class.cat+strat(site),
          data=d.imp,x=T,y=T)

ylim.lower<-.7
# hist.density.factor<-100

# warning("Below code will only run if time=1600")  ## I believe it is now fixed (2016-03-29)
# pdf("survival-5yr-age.pdf")
# plot(Predict(mod1, age, time=365*5, site="peru", male=1, aids.enrollment=0, sqrt.cd4.=sqrt(200), init.class.cat="NNRTI", year=2007),
#            xlab='Age at HAART initiation',ylab='Survival Probability after 5 years',ylim=c(ylim.lower,1),
#            adj.subtitle=FALSE)
# dev.off()


# anova(mod1)
# 
# 
# ########  For an IWHOD abstract
# 
# stuff<-Predict(mod1, age, time=5*365, site="peru", male=1, aids.enrollment=0, sqrt.cd4.=sqrt(200), init.class.cat="NNRTI", year=2007)
# 
# mod.linear.age<-cph(Surv(time,death1)~male+age+aids.enrollment+rcs(sqrt.cd4.,4)+rcs(year,4)+init.class.cat+strat(site),
#                     data=d.imp,x=T,y=T)
# stuff.lin<-Predict(mod.linear.age, age, time=5*365, site="peru", male=1, aids.enrollment=0, sqrt.cd4.=sqrt(200), 
#                    init.class.cat="NNRTI", year=2007)
# 
# d.imp$cat.age<-with(d.imp,ifelse(age<30,"<30",
#                           ifelse(age<40,"30-39",
#                           ifelse(age<50,"40-49",">=50"))))
# dd<-datadist(d.imp)
# options(datadist="dd")
# mod.cat.age<-cph(Surv(time,death1)~male+cat.age+aids.enrollment+rcs(sqrt.cd4.,4)+rcs(year,4)+init.class.cat+strat(site),
#                  data=d.imp,x=T,y=T)
# stuff.cat<-Predict(mod.cat.age, cat.age, time=5*365, site="peru", male=1, aids.enrollment=0, sqrt.cd4.=sqrt(200), 
#                    init.class.cat="NNRTI", year=2007)
# 
# pdf("splines-plot.pdf",height=4,width=8)
# par(mfrow=c(1,2),mar=c(3.5,3.5,.5,1))
# plot(rep(stuff$age,2),c(stuff$lower,stuff$upper),
#      xlim=c(18,70),ylim=c(.8,1),ylab="",xlab="",type="n")
# mtext("Age at ART initiation",side=1,line=2)
# mtext("5 Year Survival Probability",side=2,line=2)
# lines(stuff.lin$age,stuff.lin$yhat,lwd=2,col=gray(.6))
# lines(stuff$age,stuff$yhat,lwd=2)
# lines(c(18,29.9),rep(stuff.cat$yhat[stuff.cat$cat.age=="<30"],2),lty=2,lwd=2)
# lines(c(30,39.9),rep(stuff.cat$yhat[stuff.cat$cat.age=="30-39"],2),lty=2,lwd=2)
# lines(c(40,49.9),rep(stuff.cat$yhat[stuff.cat$cat.age=="40-49"],2),lty=2,lwd=2)
# lines(c(50,75),rep(stuff.cat$yhat[stuff.cat$cat.age==">=50"],2),lty=2,lwd=2)
# 
# ####  CD4 plot
# stuff<-Predict(mod1, sqrt.cd4., time=5*365, site="peru", male=1, age=40, aids.enrollment=0, init.class.cat="NNRTI", year=2007)
# 
# d.imp$cd4<-d.imp$sqrt.cd4^2
# d.imp$cat.cd4<-with(d.imp,ifelse(cd4<50,"<50",
#                           ifelse(cd4<100,"50-99",
#                           ifelse(cd4<200,"100-199",
#                           ifelse(cd4<350,"200-349",">=350")))))
# dd<-datadist(d.imp)
# options(datadist="dd")
# mod.linear.cd4<-cph(Surv(time,death1)~male+rcs(age,3)+aids.enrollment+cd4+rcs(year,4)+init.class.cat+strat(site),
#                     data=d.imp,x=T,y=T)
# stuff.lin<-Predict(mod.linear.cd4, cd4, time=5*365, site="peru", male=1, aids.enrollment=0, age=40, 
#                    init.class.cat="NNRTI", year=2007)
# 
# mod.cat.cd4<-cph(Surv(time,death1)~male+rcs(age,3)+aids.enrollment+cat.cd4+rcs(year,4)+init.class.cat+strat(site),
#                     data=d.imp,x=T,y=T)
# stuff.cat<-Predict(mod.cat.cd4, cat.cd4, time=5*365, site="peru", male=1, aids.enrollment=0, age=40, 
#                    init.class.cat="NNRTI", year=2007)
# 
# 
# plot(rep(stuff$sqrt.cd4.^2,2),c(stuff$lower,stuff$upper),
#      xlim=c(0,500),ylim=c(.8,1),ylab="",xlab="",type="n")
# mtext("CD4 at ART initiation",side=1,line=2)
# mtext("5 Year Survival Probability",side=2,line=2)
# lines(stuff.lin$cd4,stuff.lin$yhat,col=gray(.6),lwd=2)
# lines(stuff$sqrt.cd4.[stuff$sqrt.cd4.>=0]^2,stuff$yhat[stuff$sqrt.cd4.>=0],lwd=2)
# lines(c(0,49),rep(stuff.cat$yhat[stuff.cat$cat.cd4=="<50"],2),lty=2,lwd=2)
# lines(c(50,99),rep(stuff.cat$yhat[stuff.cat$cat.cd4=="50-99"],2),lty=2,lwd=2)
# lines(c(100,199),rep(stuff.cat$yhat[stuff.cat$cat.cd4=="100-199"],2),lty=2,lwd=2)
# lines(c(200,349),rep(stuff.cat$yhat[stuff.cat$cat.cd4=="200-349"],2),lty=2,lwd=2)
# lines(c(350,520),rep(stuff.cat$yhat[stuff.cat$cat.cd4==">=350"],2),lty=2,lwd=2)
# dev.off()
# 
# # plot(Predict(mod1, age, time=5*365, site="peru", loglog=TRUE),
# #      xlab='Age at HAART initiation',ylab='Survival Probability after 5 years',
# #      adj.subtitle=FALSE)
# # 
# # junk<-quantile(age,c(.05,.23,.41,.59,.77,.95))
# # for (i in 1:length(junk)) {
# #   abline(v=junk[i])
# # }

save(mod1,file="hr-model-for-plotting.Rda")

# age.hist<-hist(d.imp$age,plot=FALSE)
# age.hist.mids<-age.hist$mids
# age.hist.density<-age.hist$density
# for (i in 1:length(age.hist.mids[age.hist.mids<75])) {
#   rect(xleft=age.hist.mids[i]-2,xright=age.hist.mids[i]+2,
#        ybottom=ylim.lower,ytop=age.hist.density[i]*hist.density.factor,border="black")
# }

pred.surv.a<-apply(pred.surv.a1,2,mean)
pred.surv.b<-apply(pred.surv.b1,2,mean)
pred.surv.c<-apply(pred.surv.c1,2,mean)
pred.surv.h<-apply(pred.surv.h1,2,mean)
pred.surv.ho<-apply(pred.surv.ho1,2,mean)
pred.surv.m<-apply(pred.surv.m1,2,mean)
pred.surv.p<-apply(pred.surv.p1,2,mean)

plot(c(0,7),c(0,.2),type="n",xlab="Years",ylab="Predicted Mortality Probability")
#points(bh.time[bh.site=="site=argentina"]/365.25,1-pred.surv.a)
lines(c(0,rep(bh.time[bh.site=="site=argentina"]/365.25,each=2),30),c(0,0,rep(1-pred.surv.a,each=2)),col=2,lty=2)
lines(c(0,rep(bh.time[bh.site=="site=brazil"]/365.25,each=2),30),c(0,0,rep(1-pred.surv.b,each=2)),col=3,lty=2)
lines(c(0,rep(bh.time[bh.site=="site=chile"]/365.25,each=2),30),c(0,0,rep(1-pred.surv.c,each=2)),col=4,lty=2)
lines(c(0,rep(bh.time[bh.site=="site=haiti"]/365.25,each=2),30),c(0,0,rep(1-pred.surv.h,each=2)),col=5,lty=2)
lines(c(0,rep(bh.time[bh.site=="site=honduras"]/365.25,each=2),30),c(0,0,rep(1-pred.surv.ho,each=2)),col=6,lty=2)
lines(c(0,rep(bh.time[bh.site=="site=mexico"]/365.25,each=2),30),c(0,0,rep(1-pred.surv.m,each=2)),col=7,lty=2)
lines(c(0,rep(bh.time[bh.site=="site=peru"]/365.25,each=2),30),c(0,0,rep(1-pred.surv.p,each=2)),col=8,lty=2)

save(bh.time,bh.site,
     pred.surv.a,pred.surv.b,pred.surv.c,pred.surv.h,pred.surv.ho,pred.surv.m,pred.surv.p,
     file="predicted-survival.Rda")

#Long term mortality analysis
#Investigation of HRs over 1 year time windows for variables measured at baseline that change over time
#Giganti
#03NOV2014
#Based on BS code gabriela-cox-regression.R

#Run this code immediately following imputation
CrudeSummaryTable<-NULL
warning("had to change j in 1:7 to j in 1:5")
for (j in 1:5){
  dd<-datadist(dd1)
  options(datadist="dd")
  ests1<-ses1<-matrix(NA,M,16)
  Pars<-matrix(NA,M,13)
  VarCov<-matrix(NA,M,13^2)
  for (i in 1:M) {
    d.imp<- imputations[[i]] 
    d.imp$death1 <- as.numeric(d.imp$death1)
    d.imp$male <- as.numeric(d.imp$male)
    d.imp$aids.enrollment <- as.numeric(d.imp$aids.enrollment)
    d.imp$init.class.cat <- as.factor(as.character(d.imp$init.class.cat))
    time<-exp(d.imp$log.time.)
    death.window<-ifelse(time>floor(365.25*j),0,
                         ifelse(time<floor(365.25*(j-1)),NA,death1))
    time.window<-ifelse(time>floor(365.25*j),floor(365.25*j) -floor(365.25*(j-1)),
                        ifelse(time<floor(365.25*(j-1)),NA,time-floor(365.25*(j-1))))
    
    mod1<-cph(Surv(time.window,death.window)~male+rcs(age,4)+aids.enrollment+rcs(sqrt.cd4.,4)+rcs(year,4)+init.class.cat+strat(site),
              data=d.imp)
    stuff1<-summary(mod1,age=c(30,20),sqrt.cd4.=c(sqrt(350),sqrt(50)),year=c(2006,2000))[
      c("male","age","aids.enrollment","sqrt.cd4.","year",
        "init.class.cat - Boosted PI:NNRTI",
        "init.class.cat - Other:NNRTI"),c(4,5)]
    stuff2<-summary(mod1,age=c(30,40),sqrt.cd4.=c(sqrt(350),sqrt(100)),year=c(2006,2002))[
      c("age","sqrt.cd4.","year"),c(4,5)]
    stuff3<-summary(mod1,age=c(30,50),sqrt.cd4.=c(sqrt(350),sqrt(200)),year=c(2006,2004))[
      c("age","sqrt.cd4.","year"),c(4,5)]
    stuff4<-summary(mod1,age=c(30,60),year=c(2006,2008))[c("age","year"),c(4,5)]
    stuff5<-summary(mod1,year=c(2006,2010))[c("year"),c(4,5)]
    
    ans<-rbind(stuff1["male",],
               stuff1["age",],
               stuff2["age",],
               stuff3["age",],
               stuff4["age",],
               stuff1["aids.enrollment",],
               stuff1["sqrt.cd4.",],
               stuff2["sqrt.cd4.",],
               stuff3["sqrt.cd4.",],
               stuff1["year",],
               stuff2["year",],
               stuff3["year",],
               stuff4["year",],
               stuff5,
               stuff1["init.class.cat - Boosted PI:NNRTI",],
               stuff1["init.class.cat - Other:NNRTI",])
    
    ests1[i,]<-ans[,1]
    ses1[i,]<-ans[,2]
    
    Pars[i,]<-mod1$coeff
    VarCov[i,]<-matrix(mod1$var,nrow=1)
    
    which.age<-which(names(mod1$coeff)%in%c("age","age'","age''"))
    which.cd4<-which(names(mod1$coeff)%in%c("sqrt.cd4.","sqrt.cd4.'","sqrt.cd4.''"))
    which.year<-which(names(mod1$coeff)%in%c("year","year'","year''"))
    which.class<-which(names(mod1$coeff)%in%c("init.class.cat=Boosted PI","init.class.cat=Other"))
    
  }
  
  ests<-ests1
  ses<-ses1
  
  log.hr<-apply(ests,2,mean)
  ses.log.hr<-sqrt(apply(ses^2,2,mean)+(M+1)*apply(ests,2,var)/M)
  hr<-exp(log.hr)
  hr.lower<-exp(log.hr-1.96*ses.log.hr)
  hr.upper<-exp(log.hr+1.96*ses.log.hr)
  p.val<-2*pnorm(-abs(log.hr/ses.log.hr))
  
  warning("THIS IS THE PART WITH AN ERROR")
  mi.information<-solve(matrix(apply(VarCov,2,mean)+(M+1)*apply(VarCov,2,var)/M,nrow=13,ncol=13))
  mean.Pars<-apply(Pars,2,mean)
  pval.age.d<-1-pchisq(mean.Pars[which.age]%*%mi.information[which.age,which.age]%*%mean.Pars[which.age],length(which.age))
  pval.cd4.d<-1-pchisq(mean.Pars[which.cd4]%*%mi.information[which.cd4,which.cd4]%*%mean.Pars[which.cd4],length(which.cd4))
  pval.year.d<-1-pchisq(mean.Pars[which.year]%*%mi.information[which.year,which.year]%*%mean.Pars[which.year],length(which.year))
  pval.init.class.cat.d<-1-pchisq(mean.Pars[which.class]%*%mi.information[which.class,which.class]%*%mean.Pars[which.class],length(which.class))
  
  hr.adj.d<-data.frame(Window=paste("Year ",j-1,sep=""), DeathsDuringWindow=sum(death.window==1,na.rm=TRUE),label=c("male","age 20:30","age 40:30","age 50:30","age 60:30","aids.enrollment",
                                                                                                                    "cd4 50:350","cd4 100:350","cd4 200:350",
                                                                                                                    "year 2000:2006","year 2002:2006","year 2004:2006","year 2008:2006","year 2010:2006",
                                                                                                                    "init.class.cat Boosted PI:NNRTI","init.class.cat Other:NNRTI"),
                       cbind(hr,hr.lower,hr.upper,p.val))
  
  #Quick approach to combine analysis based on windows for each of first 7 years
  #Needs to be prettified
  CrudeSummaryTable<-rbind(CrudeSummaryTable,hr.adj.d)
}

#Quick output of three "baseline" variables that we suspect may have differing HRs over different windows
CrudeSummaryTable[CrudeSummaryTable$label=="cd4 50:350",]
CrudeSummaryTable[CrudeSummaryTable$label=="init.class.cat Boosted PI:NNRTI",]
CrudeSummaryTable[CrudeSummaryTable$label=="aids.enrollment",]
CrudeSummaryTable[CrudeSummaryTable$label=="age 40:30",]
CrudeSummaryTable[CrudeSummaryTable$label=="male",]

# plot(c(1,7),log10(c(0.2,5)),type="n", xlab="Year after HAART", ylab="HR for CD4=50 vs. 350",axes=FALSE)
# points(1:7,log10(CrudeSummaryTable[CrudeSummaryTable$label=="cd4 50:350","hr"]),pch=3)
# axis(1)
# axis(2,at=log10(c(5,3,2,1,.5,1/3,1/5)), label=c(5,3,2,1,0.5,0.33,.2))
# for (i in 1:7){
#   lines(c(i,i), c(log10(CrudeSummaryTable[CrudeSummaryTable$label=="cd4 50:350","hr.lower"][i]),
#                   log10(CrudeSummaryTable[CrudeSummaryTable$label=="cd4 50:350","hr.upper"][i])))
# }
# abline(h=0,lty=2)


#######  Now I'm doing analyses dichotomizing age at <50, >=50.

age.ge50<-ifelse(age<50,0,1)
mod.age.ge50.death<-coxph(Surv(time,death1)~age.ge50+strata(site))
summary(mod.age.ge50.death)

hr50.crude<-summary(mod.age.ge50.death)$conf.int[1]
lower50.crude<-summary(mod.age.ge50.death)$conf.int[3]
upper50.crude<-summary(mod.age.ge50.death)$conf.int[4]


junk<-dd1
junk$age.ge.50<-ifelse(junk$age<50,0,1)
dd<-datadist(junk)
options(datadist="dd")
age50.coeff<-rep(NA,M)
age50.var<-rep(NA,M)
for (i in 1:M) {
  d.imp<-imputations[[i]]
  d.imp$death1 <- as.numeric(d.imp$death1)
  d.imp$male <- as.numeric(d.imp$male)
  d.imp$aids.enrollment <- as.numeric(d.imp$aids.enrollment)
  d.imp$init.class.cat <- as.factor(as.character(d.imp$init.class.cat))
  d.imp$age.ge.50<-with(d.imp, ifelse(age<50,0,1))
  
  mod1<-cph(Surv(exp(log.time.),death1)~male+age.ge.50+aids.enrollment+rcs(sqrt.cd4.,4)+rcs(year,4)+init.class.cat+strat(site),
            data=d.imp)
  
  stuff1<-summary(mod1,age.ge.50=c(0,1))["age.ge.50",c(4,5)]
  
  age50.coeff[i]<-stuff1[1]
  age50.var[i]<-stuff1[2]^2
}

hr50<-exp(mean(age50.coeff))
se50<-sqrt(mean(age50.var)+(M+1)*var(age50.coeff)/M)
lower50<-exp(mean(age50.coeff)-1.96*se50)
upper50<-exp(mean(age50.coeff)+1.96*se50)

save(hr50,lower50,upper50,hr50.crude,lower50.crude,upper50.crude,file="hr-age50.Rda")


###################################################################

# Now removing Haiti and using a few more covariates

rm(list=ls())

load("d-second-chunk.Rda")

library(survival)
library(rms)
library(mvtnorm)
library(mi)


d<-d[which(d$time>0),]
d<-d[d$site!="haiti",]

d<-within(d,{
  site<-as.factor(as.character(site))
})



#### Univariate analyses

d$male<-as.numeric(d$male)

time<-d$time
death1<-d$death1
site<-d$site
male<-d$male
age<-d$age
cd4<-d$nadir.cd4.prehaart
year<-d$year.init
aids.enrollment<-ifelse(d$aids.enrollment=="Unknown",NA,ifelse(d$aids.enrollment=="AIDS",1,0))
init.class.cat<-ifelse(d$init.class=="Other"|d$init.class=="Unboosted PI",
                       "Other",as.character(d$init.class))
init.class.cat<-factor(init.class.cat, levels=c("NNRTI","Boosted PI","Other"), ordered=TRUE)
route.heterosex<-ifelse(d$route=="unknown",NA,ifelse(d$route=="heterosexual",1,0))
route1<-factor(ifelse(d$route=="unknown"|d$route=="other","Other/Missing",d$route))
logvl<-log10(abs(d$rna1))

dd<-datadist(time,death1,site,male,age,cd4,year,aids.enrollment,init.class.cat,route.heterosex,logvl)
options(datadist="dd")

mod.male.death<-coxph(Surv(time,death1)~male+strata(site))
mod.age.death<-cph(Surv(time,death1)~rcs(age,4)+strat(site))
mod.aids.death<-coxph(Surv(time,death1)~aids.enrollment+strata(site))
mod.cd4.death<-cph(Surv(time,death1)~rcs(sqrt(cd4),4)+strat(site))
mod.year.death<-cph(Surv(time,death1)~rcs(year,4)+strat(site))   #removed non-linear piece
mod.class.death<-coxph(Surv(time,death1)~init.class.cat+strata(site))
#mod.route.death<-coxph(Surv(time,death1)~route.heterosex+strata(site))
mod.route.death<-coxph(Surv(time,death1)~route1+strata(site))
mod.logvl.death<-cph(Surv(time,death1)~rcs(logvl,4)+strat(site))

hr.male.d<-summary(mod.male.death)$conf.int[c(1,3,4)]
p.male.d<-summary(mod.male.death)$logtest[3]

p.age.d<-anova(mod.age.death)[3,3]
hr.age.d<-rbind(summary(mod.age.death,age=c(30,20))[2,c(4,6,7)],
                summary(mod.age.death,age=c(30,40))[2,c(4,6,7)],
                summary(mod.age.death,age=c(30,50))[2,c(4,6,7)],
                summary(mod.age.death,age=c(30,60))[2,c(4,6,7)])

hr.aids.d<-summary(mod.aids.death)$conf.int[c(1,3,4)]
p.aids.d<-summary(mod.aids.death)$logtest[3]

p.cd4.d<-anova(mod.cd4.death)[3,3]
hr.cd4.d<-rbind(summary(mod.cd4.death,cd4=c(350,50))[2,c(4,6,7)],
                summary(mod.cd4.death,cd4=c(350,100))[2,c(4,6,7)],
                summary(mod.cd4.death,cd4=c(350,200))[2,c(4,6,7)])

p.year.d<-anova(mod.year.death)[3,3]
hr.year.d<-rbind(summary(mod.year.death,year=c(2006,2000))[2,c(4,6,7)],
                 summary(mod.year.death,year=c(2006,2002))[2,c(4,6,7)],
                 summary(mod.year.death,year=c(2006,2004))[2,c(4,6,7)],
                 summary(mod.year.death,year=c(2006,2008))[2,c(4,6,7)],
                 summary(mod.year.death,year=c(2006,20010))[2,c(4,6,7)])

hr.class.d<-summary(mod.class.death)$conf.int[,c(1,3,4)]
p.class.d<-c(summary(mod.class.death)$logtest[3],
             summary(mod.class.death)$coeff[,5])

hr.route.d<-summary(mod.route.death)$conf.int[,c(1,3,4)]
p.route.d<-c(summary(mod.route.death)$logtest[3],
             summary(mod.route.death)$coeff[,5])

p.logvl.d<-anova(mod.logvl.death)[3,3]
hr.logvl.d<-rbind(summary(mod.logvl.death,logvl=c(3,5))[2,c(4,6,7)],
                  summary(mod.logvl.death,logvl=c(4,5))[2,c(4,6,7)],
                  summary(mod.logvl.death,logvl=c(6,5))[2,c(4,6,7)])


save(hr.male.d,hr.age.d,hr.cd4.d,hr.year.d,hr.aids.d,hr.class.d,hr.route.d,hr.logvl.d,
     p.male.d, p.age.d, p.cd4.d, p.year.d, p.aids.d, p.class.d, p.route.d, p.logvl.d,
     file="hr-death-unadjust-no-haiti.Rda")




#### Multiple imputation 

d.analysis<-data.frame(male,age,sqrt(cd4),year,site,
                       log(time),death1,log(time)*death1,aids.enrollment,
                       init.class.cat,route1,logvl)

M<-10
IMP<-mi(d.analysis,n.chains=M,seed=20121129)     # The actual imputation

#save(IMP,file="imputed-data-no-haiti.Rda")

dd1 <- data.frame(complete(IMP,m=1))
dd1$death1 <- as.numeric(dd1$death1)
dd1$init.class.cat <- as.factor(as.character(dd1$init.class.cat))
dd1$aids.enrollment <- as.numeric(dd1$aids.enrollment)
dd1$male <- as.numeric(dd1$male)
dd<-datadist(dd1)
options(datadist="dd")

imputations <- complete(IMP,m=10)

ests1<-ses1<-matrix(NA,M,22)
Pars<-matrix(NA,M,19)
VarCov<-matrix(NA,M,19^2)
for (i in 1:M) {
  d.imp<-imputations[[i]]
  d.imp$death1 <- as.numeric(d.imp$death1)
  d.imp$male <- as.numeric(d.imp$male)
  d.imp$aids.enrollment <- as.numeric(d.imp$aids.enrollment)
  d.imp$init.class.cat <- as.factor(as.character(d.imp$init.class.cat))
  
  mod1<-cph(Surv(exp(log.time.),death1)~male+rcs(age,4)+aids.enrollment+rcs(sqrt.cd4.,4)+rcs(year,4)+init.class.cat+
                                        route1+rcs(logvl,4)+strat(site),
            data=d.imp)
  stuff1<-summary(mod1,age=c(30,20),sqrt.cd4.=c(sqrt(350),sqrt(50)),year=c(2006,2000),logvl=c(5,3),route1="heterosexual")[
    c("male","age","aids.enrollment","sqrt.cd4.","year",
      "init.class.cat - Boosted PI:NNRTI",
      "init.class.cat - Other:NNRTI","logvl",
      "route1 - homo/bisexual:heterosexual","route1 - IDU:heterosexual","route1 - Other/Missing:heterosexual"),c(4,5)]
  stuff2<-summary(mod1,age=c(30,40),sqrt.cd4.=c(sqrt(350),sqrt(100)),year=c(2006,2002),logvl=c(5,4))[
    c("age","sqrt.cd4.","year","logvl"),c(4,5)]
  stuff3<-summary(mod1,age=c(30,50),sqrt.cd4.=c(sqrt(350),sqrt(200)),year=c(2006,2004),logvl=c(5,6))[
    c("age","sqrt.cd4.","year","logvl"),c(4,5)]
  stuff4<-summary(mod1,age=c(30,60),year=c(2006,2008))[c("age","year"),c(4,5)]
  stuff5<-summary(mod1,year=c(2006,2010))[c("year"),c(4,5)]
  
  ans<-rbind(stuff1["male",],
             stuff1["age",],
             stuff2["age",],
             stuff3["age",],
             stuff4["age",],
             stuff1["aids.enrollment",],
             stuff1["sqrt.cd4.",],
             stuff2["sqrt.cd4.",],
             stuff3["sqrt.cd4.",],
             stuff1["year",],
             stuff2["year",],
             stuff3["year",],
             stuff4["year",],
             stuff5,
             stuff1["init.class.cat - Boosted PI:NNRTI",],
             stuff1["init.class.cat - Other:NNRTI",],
             stuff1["route1 - homo/bisexual:heterosexual",],
             stuff1["route1 - IDU:heterosexual",],
             stuff1["route1 - Other/Missing:heterosexual",],
             stuff1["logvl",],
             stuff2["logvl",],
             stuff3["logvl",])
  
  ests1[i,]<-ans[,1]
  ses1[i,]<-ans[,2]
  
  Pars[i,]<-mod1$coeff
  VarCov[i,]<-matrix(mod1$var,nrow=1)
  
  which.age<-which(names(mod1$coeff)%in%c("age","age'","age''"))
  which.cd4<-which(names(mod1$coeff)%in%c("sqrt.cd4.","sqrt.cd4.'","sqrt.cd4.''"))
  which.year<-which(names(mod1$coeff)%in%c("year","year'","year''"))
  which.class<-which(names(mod1$coeff)%in%c("init.class.cat=Boosted PI","init.class.cat=Other"))
  which.route<-which(names(mod1$coeff)%in%c("route1=homo/bisexual","route1=IDU","route1=Other/Missing"))
  which.logvl<-which(names(mod1$coeff)%in%c("logvl","logvl'","logvl''"))
  
}

ests<-ests1
ses<-ses1

log.hr<-apply(ests,2,mean)
ses.log.hr<-sqrt(apply(ses^2,2,mean)+(M+1)*apply(ests,2,var)/M)
hr<-exp(log.hr)
hr.lower<-exp(log.hr-1.96*ses.log.hr)
hr.upper<-exp(log.hr+1.96*ses.log.hr)
p.val<-2*pnorm(-abs(log.hr/ses.log.hr))

mi.information<-solve(matrix(apply(VarCov,2,mean)+(M+1)*apply(VarCov,2,var)/M,nrow=19,ncol=19))
mean.Pars<-apply(Pars,2,mean)
pval.age.d<-1-pchisq(mean.Pars[which.age]%*%mi.information[which.age,which.age]%*%mean.Pars[which.age],length(which.age))
pval.cd4.d<-1-pchisq(mean.Pars[which.cd4]%*%mi.information[which.cd4,which.cd4]%*%mean.Pars[which.cd4],length(which.cd4))
pval.year.d<-1-pchisq(mean.Pars[which.year]%*%mi.information[which.year,which.year]%*%mean.Pars[which.year],length(which.year))
pval.init.class.cat.d<-1-pchisq(mean.Pars[which.class]%*%mi.information[which.class,which.class]%*%mean.Pars[which.class],length(which.class))
pval.route.d<-1-pchisq(mean.Pars[which.route]%*%mi.information[which.route,which.route]%*%mean.Pars[which.route],length(which.route))
pval.logvl.d<-1-pchisq(mean.Pars[which.logvl]%*%mi.information[which.logvl,which.logvl]%*%mean.Pars[which.logvl],length(which.logvl))

hr.adj.d<-data.frame(label=c("male","age 20:30","age 40:30","age 50:30","age 60:30","aids.enrollment",
                             "cd4 50:350","cd4 100:350","cd4 200:350",
                             "year 2000:2006","year 2002:2006","year 2004:2006","year 2008:2006","year 2010:2006",
                             "init.class.cat Boosted PI:NNRTI","init.class.cat Other:NNRTI",
                             "route homosexual:heterosexual","route IDU:heterosexual","route other/missing:heterosexual",
                             "logvl 3:5", "logvl 4:5", "logvl 6:5"),
                     cbind(hr,hr.lower,hr.upper,p.val))

save(hr.adj.d,pval.age.d,pval.cd4.d,pval.year.d,pval.init.class.cat.d,pval.logvl.d,pval.route.d,
     file="hr-death-adjust-no-haiti.Rda")



d.imp<-dd1
d.imp$time<-exp(d.imp$log.time.)
mod1<-cph(Surv(time,death1)~male+rcs(age,4)+aids.enrollment+rcs(sqrt.cd4.,4)+rcs(year,4)+init.class.cat+
                            route1+rcs(logvl,4)+strat(site),
          data=d.imp,x=T,y=T)

ylim.lower<-.7
# hist.density.factor<-100

# plot(Predict(mod1, age, time=5*365, site="peru", male=1, aids.enrollment=0, sqrt.cd4.=sqrt(200), init.class.cat="NNRTI", year=2007,
#              logvl=5,route1="heterosexual"),
#      xlab='Age at HAART initiation',ylab='Survival Probability after 5 years',ylim=c(ylim.lower,1),
#      adj.subtitle=FALSE)
# 
# anova(mod1)


save(mod1,file="hr-model-for-plotting-no-haiti.Rda")



#######  Now I'm doing analyses dichotomizing age at <50, >=50.

age.ge50<-ifelse(age<50,0,1)
mod.age.ge50.death<-coxph(Surv(time,death1)~age.ge50+strata(site))
summary(mod.age.ge50.death)

hr50.crude.nh<-summary(mod.age.ge50.death)$conf.int[1]
lower50.crude.nh<-summary(mod.age.ge50.death)$conf.int[3]
upper50.crude.nh<-summary(mod.age.ge50.death)$conf.int[4]


junk<-dd1
junk$age.ge.50<-ifelse(junk$age<50,0,1)
dd<-datadist(junk)
options(datadist="dd")
age50.coeff<-rep(NA,M)
age50.var<-rep(NA,M)
for (i in 1:M) {
  d.imp<-imputations[[i]]
  d.imp$death1 <- as.numeric(d.imp$death1)
  d.imp$male <- as.numeric(d.imp$male)
  d.imp$aids.enrollment <- as.numeric(d.imp$aids.enrollment)
  d.imp$init.class.cat <- as.factor(as.character(d.imp$init.class.cat))
  d.imp$age.ge.50<-with(d.imp, ifelse(age<50,0,1))
  
  mod1<-cph(Surv(exp(log.time.),death1)~male+age.ge.50+aids.enrollment+rcs(sqrt.cd4.,4)+rcs(year,4)+init.class.cat+strat(site),
            data=d.imp)
  
  stuff1<-summary(mod1,age.ge.50=c(0,1))["age.ge.50",c(4,5)]
  
  age50.coeff[i]<-stuff1[1]
  age50.var[i]<-stuff1[2]^2
}

hr50.nh<-exp(mean(age50.coeff))
se50<-sqrt(mean(age50.var)+(M+1)*var(age50.coeff)/M)
lower50.nh<-exp(mean(age50.coeff)-1.96*se50)
upper50.nh<-exp(mean(age50.coeff)+1.96*se50)

save(hr50.nh,lower50.nh,upper50.nh,hr50.crude.nh,lower50.crude.nh,upper50.crude.nh,file="hr-age50-no-haiti.Rda")


